dataf.growth <- function() return(structure(list(
  name = "Berkeley Growth Study",
  args = "age",
  vals = "height",
  dataf = list(structure(list(args = c(1, 1.25, 
1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 
12, 12.5, 13, 13.5, 14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18
), vals = structure(c(76.2, 80.4, 83.3, 85.7, 87.7, 96, 103.8, 
110.7, 116.8, 122.2, 127.4, 130.6, 133.4, 135.9, 138.6, 142.4, 
146.8, 150.3, 153.1, 155, 156.2, 157.1, 157.7, 158, 158.2, 158.4, 
158.6, 158.7, 158.7, 158.8, 158.9), .Names = c("1", "1.25", "1.5", 
"1.75", "2", "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", 
"10", "10.5", "11", "11.5", "12", "12.5", "13", "13.5", "14", 
"14.5", "15", "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(74.6, 
78, 82, 86.9, 90, 94.9, 102.1, 109.2, 115.6, 122.7, 128.2, 131.1, 
134.8, 138.2, 140.9, 143.4, 146.1, 149.4, 152.9, 156.4, 159.5, 
161.6, 162.6, 163.6, 165, 165.3, 165.6, 165.9, 166.1, 166, 166
), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", "5", 
"6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(78.2, 81.8, 
    85.4, 87.9, 89.6, 97.1, 109.2, 116.2, 122.9, 128, 134.2, 
    138, 141.5, 145.2, 148.8, 152.3, 155.6, 158.2, 159.6, 160.1, 
    160.3, 160.8, 161.6, 161.8, 161.7, 161.8, 161.9, 161.9, 161.7, 
    161.9, 162.2), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(77.7, 
80.5, 83.3, 87, 90.3, 98.6, 106.3, 113.9, 120.7, 125.7, 131, 
134.1, 137.1, 140.2, 143, 145.7, 148.5, 151.5, 154.8, 158.4, 
161.2, 163.5, 165.2, 166, 166.5, 166.9, 167.2, 167.4, 167.4, 
167.6, 167.8), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76, 
80, 83, 86, 89, 96, 103, 110, 117, 123, 131, 133, 136, 139, 141, 
144, 147, 150, 153, 157, 161, 164, 166, 167, 168, 168, 169, 169, 
170, 170, 170), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(73.5, 
77, 81.5, 83.8, 85.5, 92.9, 99.6, 106.7, 113.3, 118.4, 124.2, 
127.6, 130.6, 133.6, 136.4, 139.7, 143.7, 148, 152, 155.7, 158.9, 
160.9, 162.2, 163.2, 163.8, 164, 164.2, 164.4, 164.4, 164.8, 
164.9), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(67.4, 72.3, 
    75.9, 79.4, 82.2, 91.6, 99.5, 105.7, 112.5, 117.2, 122.8, 
    125.5, 128, 130.3, 132.5, 134.9, 137.4, 139.9, 142.1, 144.2, 
    146.4, 148.9, 152.2, 155.3, 157.9, 160.1, 161.6, 162.4, 163, 
    163.4, 164), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(80.5, 
85.1, 89.7, 93.7, 97.3, 106.3, 114.4, 123.5, 130.6, 137.7, 144.4, 
148.4, 152.5, 156.6, 161.5, 166.1, 170.2, 173.5, 176, 177.3, 
178.3, 179.1, 180, 181, 181.6, 181.9, 182.3, 182.6, 182.8, 182.7, 
183.2), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(77, 80.7, 
    83.4, 85.6, 88.9, 96.5, 104.2, 111.4, 118.2, 124.2, 129.6, 
    132, 135.2, 138.5, 141.5, 144.9, 148.9, 152.6, 156.2, 159.6, 
    161.4, 162.4, 163.1, 163.6, 164.3, 164.5, 164.4, 164.3, 164.1, 
    164, 163.8), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(74.7, 
77.9, 81.3, 84.8, 87.6, 98.6, 107.8, 116.2, 124.6, 130.6, 136.2, 
139.3, 142.3, 145.5, 148.7, 152.3, 156.6, 161, 164.7, 167.5, 
169.1, 170.2, 171.3, 172.1, 172.6, 172.9, 173.1, 173.3, 173.6, 
173.8, 174), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(69.3, 
76.1, 80.7, 84.4, 87.1, 94.6, 103.4, 110, 116.6, 122.6, 128.1, 
130.4, 133.2, 135.8, 138.2, 140.7, 142.7, 144.4, 146.2, 148.5, 
151.3, 154.6, 158.3, 161.4, 163.5, 165, 166, 166.5, 166.7, 166.9, 
167.1), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(72.4, 75.2, 
    77.8, 80.7, 83.6, 95.3, 102.4, 109.6, 116, 121.7, 127.7, 
    130.1, 133.1, 135.5, 137.5, 140, 143.1, 146.8, 150.7, 154.2, 
    157, 159, 160.5, 161.5, 162.1, 162.5, 162.7, 163, 163.4, 
    163.1, 163), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(67.3, 
73.7, 76.2, 79, 81.4, 90.2, 96.8, 102.4, 108.7, 113.8, 118.8, 
121.1, 123.2, 125.4, 127.7, 129.9, 131.6, 133.5, 135.6, 137.6, 
139.5, 141.8, 145, 148.2, 150.8, 152.2, 153, 153.6, 154.1, 154.4, 
154.6), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76.7, 80, 
    83.8, 86.8, 89.7, 96.2, 104.5, 111.5, 118.6, 125, 130.5, 
    133, 135.8, 138.6, 141.4, 144.2, 146.6, 148.8, 151.4, 154.6, 
    157.8, 161.2, 164.5, 166.6, 167.8, 168.6, 169.2, 169.8, 169.8, 
    170, 170.3), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(72.8, 
78.2, 84.2, 87, 88.4, 94.4, 100.3, 106.6, 120.5, 127.3, 133.6, 
136.4, 139.5, 142.5, 146, 150.2, 154.3, 158.6, 162.6, 164.7, 
166, 167.1, 168.3, 168.7, 169.1, 169.5, 169.9, 170.1, 170.3, 
170.3, 170.6), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(72, 
74.9, 80, 82.8, 83.8, 92.3, 98.2, 105.2, 110.4, 115.6, 119.4, 
121.9, 124.2, 126.3, 128.5, 131.2, 134.3, 137.3, 140.5, 143.6, 
146.8, 149, 150.2, 151.4, 152.6, 153.4, 154.1, 154.9, 155.7, 
156.2, 156.5), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(68.4, 
75, 81.3, 85, 87.6, 94.6, 102.4, 109.2, 116.2, 122.7, 129.4, 
132.4, 135.6, 139.4, 143.6, 147.9, 151.9, 155, 157, 158, 158.9, 
159.4, 159.7, 159.9, 160.2, 160.2, 160.3, 160.4, 160.4, 160.3, 
160.3), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76, 82.1, 
    87.5, 91.1, 94, 101.1, 108.8, 116.7, 124.7, 132.3, 138.2, 
    141.2, 144.1, 146.8, 150.2, 153.9, 157.3, 161, 164.5, 166.8, 
    168, 168.7, 169.3, 169.6, 169.8, 170.1, 170.3, 170.5, 170.6, 
    170.8, 170.8), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(73.7, 
78.2, 79.9, 82, 86.4, 95.7, 101.9, 110, 117.6, 122.7, 128.7, 
131.6, 134.6, 137.6, 141.6, 146.9, 152.1, 156.3, 159.4, 161, 
162, 162.8, 163.6, 164.2, 164.6, 164.9, 165, 165.1, 165.1, 165.1, 
165.2), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(73.7, 81.3, 
    83.8, 85.1, 88.9, 96.1, 106.1, 113, 119.1, 124.7, 130.7, 
    134, 137.2, 140.9, 144.2, 147.3, 150.2, 154.2, 158.4, 161.2, 
    163.9, 165.4, 166.8, 167.5, 168.2, 168.8, 169.5, 169.6, 169.6, 
    169.6, 169.8), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(74.4, 
77.5, 81.5, 84.5, 86.7, 95, 103.6, 112, 119.6, 127.5, 133.2, 
136.6, 139.8, 142.7, 146, 150.3, 154.4, 158.3, 162.4, 165.5, 
167.9, 169.4, 170.1, 170.2, 170.6, 171.1, 171.5, 171.5, 171.5, 
171.4, 171.2), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(74.9, 
77.8, 81.2, 83.7, 86.4, 94.2, 98.6, 107.7, 114.8, 122.7, 128.3, 
131, 134.2, 137.8, 141.4, 145.4, 149.7, 153.9, 157, 159.1, 160.4, 
161.2, 161.8, 162.4, 163, 163.1, 163.1, 163.3, 163.6, 163.7, 
163.8), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(72, 77.1, 
    80.6, 83.4, 85.9, 94, 100.3, 108, 114.9, 121.2, 127, 129.6, 
    132.1, 134.8, 137.8, 141.6, 145.8, 150.2, 153.8, 156.7, 158.8, 
    159.7, 160.5, 161.1, 161.5, 161.7, 162.1, 162.3, 162.4, 162.4, 
    162.4), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
    "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(72.6, 
76.8, 80.4, 82.9, 85.1, 91.4, 96.8, 105.7, 114.8, 118.4, 122.6, 
126.1, 129, 131.3, 133.9, 136.7, 140.1, 143.8, 147.3, 150.4, 
153, 154.5, 155.6, 156.1, 156.4, 156.6, 156.8, 156.9, 157, 156.9, 
157.1), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(75.2, 80.2, 
    83.8, 86.4, 88.6, 97.5, 103.6, 110.7, 117.6, 126.5, 132.6, 
    136.1, 139.4, 142.4, 145.6, 148.8, 152.2, 155.7, 159, 162.1, 
    166, 170.3, 174.3, 177.2, 178.9, 179.7, 180.4, 180.4, 180.2, 
    180.5, 181.1), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(70.9, 
74.3, 76.8, 80, 83, 91.4, 96.5, 102.4, 108.7, 114.6, 120.4, 123, 
125.6, 127.9, 130.1, 132.8, 135.5, 138.9, 142.9, 146.9, 150, 
152.2, 153.6, 154.9, 155.9, 156.6, 157.1, 157.5, 157.7, 158, 
158.4), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(74.6, 79.4, 
    82, 84.3, 88.9, 98, 105, 113.5, 121, 126.2, 131.4, 134.2, 
    137.1, 139.5, 141.9, 145, 148.1, 151.8, 155.6, 158.3, 160.3, 
    161.8, 162.8, 163.5, 164, 164.3, 164.8, 165.2, 165.4, 165.5, 
    165.6), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
    "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(71.1, 
77.3, 81.7, 85.5, 89.7, 98.2, 106, 112.6, 118.6, 123.7, 128.6, 
131.1, 133.6, 135.8, 138, 141.8, 145.8, 150.5, 155.2, 158.7, 
161, 162.6, 163.9, 164.7, 165.5, 165.9, 166.3, 166.5, 166.6, 
166.7, 166.7), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(71, 
72.3, 74.9, 78.4, 81.3, 88.1, 94.7, 100.1, 105.7, 112.5, 117, 
119.2, 121.4, 124.5, 126.8, 129, 131.7, 134.4, 137, 140.3, 143.9, 
147, 149.6, 151.8, 153.2, 154.3, 155.1, 155.6, 156, 156.1, 156.5
), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", "5", 
"6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(74, 77.6, 
    82.3, 86.2, 88.7, 95.3, 103.6, 109.7, 116.6, 122.2, 127.2, 
    130.4, 133.6, 135.7, 137.8, 140.5, 143.5, 147.5, 151.7, 155.7, 
    159.2, 162, 163.8, 164.9, 165.8, 166.8, 167.5, 167.9, 168.2, 
    168.2, 168.1), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(78.7, 
82, 84.4, 86.4, 88.4, 96.8, 104.7, 111.3, 118.8, 124.3, 129, 
131.6, 134.1, 136.3, 139, 141.9, 145.1, 148.3, 151.3, 154.6, 
157.7, 160.3, 161.4, 162.4, 163.4, 164, 164.3, 164.7, 165.2, 
165.3, 165.3), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(69, 
72.9, 76.7, 80.8, 85.1, 94.6, 104.1, 112.5, 120.7, 126.2, 133.3, 
136.4, 139.4, 142.7, 146.1, 149.9, 154.1, 157.8, 160.4, 161.9, 
162.6, 162.9, 163, 163.1, 163, 163.1, 163.1, 163.4, 163.7, 163.8, 
163.7), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(72.7, 78.3, 
    82.4, 87.2, 91.4, 98.3, 105.2, 113.3, 120.1, 126.2, 131.5, 
    134.9, 138.1, 140, 142.2, 145.2, 148.3, 151, 153.9, 156.9, 
    160.3, 163.9, 166.9, 169.1, 170.4, 171.3, 172, 172.7, 172.9, 
    173.1, 173.7), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(72.6, 
77.4, 81.8, 85.2, 87.6, 95.5, 103.7, 109.7, 115.8, 121.6, 127.6, 
130.4, 133.2, 135.8, 138.4, 141.8, 145.8, 150.3, 154.3, 157, 
158.7, 159.9, 160.9, 161.7, 162.4, 163, 163.3, 163.4, 163.5, 
163.6, 163.9), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(75.3, 
79.7, 82, 84.2, 86.1, 96, 103.5, 111.4, 119.1, 126, 132.7, 135.6, 
138.4, 141, 143.8, 146.9, 150.6, 154.4, 157.9, 161.1, 163.6, 
165, 166.2, 167.3, 167.9, 168.1, 168.3, 168.5, 168.6, 168.8, 
169.2), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(73.1, 77.5, 
    80.4, 82.8, 85.9, 94.6, 102.4, 107.7, 114.6, 121.7, 126.8, 
    129.8, 132.8, 135.3, 137.6, 140.3, 143.7, 147.3, 150.6, 154.1, 
    157.5, 160.1, 162.2, 163.5, 164.2, 164.6, 164.8, 165.1, 165.4, 
    165.7, 166), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(68.9, 
72.7, 76.6, 79.6, 82.2, 91, 98.4, 106.2, 112.3, 118.1, 123.6, 
126.7, 129.8, 132.3, 135, 137.4, 139.9, 142.4, 145, 148.1, 151.8, 
155.5, 158.3, 160.1, 161.3, 162.3, 163, 163.3, 163.6, 163.8, 
164.2), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(75.9, 79.4, 
    82.1, 85.7, 88.2, 98, 107.4, 115.3, 124, 130.6, 137.6, 141.2, 
    144.8, 148, 151.8, 155.3, 158.7, 162.2, 165.5, 168.3, 170.7, 
    172.3, 173.4, 174.5, 175.1, 175.2, 175.2, 175.4, 175.8, 176.1, 
    176), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
    "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
    "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
    "16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(73, 
77.3, 81, 85.1, 87.5, 97.3, 105.7, 112.7, 119.3, 124.7, 131.9, 
135.4, 138.9, 142, 145, 148.2, 152, 156.5, 160.5, 163.6, 165.9, 
167.6, 168.8, 169.5, 169.9, 170.2, 170.5, 170.5, 170.5, 170.7, 
170.9), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(80, 83.6, 
    85.1, 86.4, 88.6, 98, 105.7, 112.5, 119.6, 126.5, 133.6, 
    137, 140.3, 142.8, 146, 149.9, 154.3, 158.3, 161.2, 163.3, 
    165.1, 166.6, 167.4, 167.8, 168.2, 168.6, 168.8, 168.9, 168.9, 
    169, 169.2), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(72.4, 
75.8, 79, 83.1, 86.4, 94.5, 101.5, 108.7, 114.8, 120.4, 126.6, 
130.1, 133.6, 136.3, 139.5, 143, 146.7, 150.5, 153.7, 156.1, 
158, 159.7, 160.4, 160.8, 161.4, 162.1, 162.6, 162.6, 162.6, 
162.8, 163), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(69, 
72.6, 76.2, 78.5, 80.9, 89.3, 94.7, 100.3, 106.9, 112.8, 117.8, 
120.6, 123.5, 126, 128.4, 131.1, 134.2, 137.7, 141.3, 145, 147.7, 
149.8, 151.5, 152.4, 152.9, 153.2, 153.6, 154.1, 154.4, 154.5, 
154.5), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76, 80, 
    84.2, 87.4, 90, 101.2, 109.5, 116.3, 122.1, 128.8, 133.8, 
    136.9, 139.9, 143.6, 147, 151, 155.8, 160.7, 164.5, 166.9, 
    168.5, 169.4, 170.1, 170.8, 171.5, 172, 172.1, 172.2, 172.3, 
    172.2, 172.5), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(78.4, 
82.6, 85.1, 86.4, 89.7, 96.6, 105, 112.3, 119.6, 124.7, 131.2, 
133.6, 135.8, 138.8, 141.2, 144.1, 147.4, 150.4, 153.8, 157.8, 
161.1, 163.5, 165.2, 166.1, 166.6, 166.8, 167.1, 167.2, 167.3, 
167.3, 167.2), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(74.8, 
78, 81.6, 84.2, 86.4, 94, 101.8, 110, 116.8, 121.9, 126.8, 129.3, 
131.9, 134.9, 137.8, 141.3, 145, 149.5, 153.8, 157, 158.9, 160.3, 
161.8, 162.4, 162.8, 163.2, 163.6, 163.9, 164.3, 164.2, 164), .Names = c("1", 
"1.25", "1.5", "1.75", "2", "3", "4", "5", "6", "7", "8", "8.5", 
"9", "9.5", "10", "10.5", "11", "11.5", "12", "12.5", "13", "13.5", 
"14", "14.5", "15", "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(71.3, 
74.4, 77.4, 80, 82.6, 91.6, 100.6, 106.2, 114.3, 120.4, 126.7, 
129.9, 133.1, 136, 138.8, 142.9, 146.8, 150.7, 154.6, 157.2, 
158.6, 159.7, 160.5, 160.8, 161.1, 161.3, 161.6, 161.9, 162, 
162.1, 162.1), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(73, 
75, 77.6, 81.7, 86.4, 92.9, 99.3, 105.6, 113.3, 118.6, 125.6, 
128.2, 130.9, 134.4, 137.9, 141.6, 145.4, 149.4, 153.3, 156.2, 
157.4, 158.1, 158.9, 159.6, 159.9, 160.2, 161, 161.5, 161.9, 
161.8, 161.6), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(71.1, 
73.7, 76.2, 79.4, 81.8, 91.4, 95.3, 102.4, 110, 116.1, 120.9, 
123.6, 126.3, 130.4, 134.4, 137.7, 141.3, 144.4, 147, 149.1, 
150.3, 151, 151.4, 151.7, 152, 152.1, 152.3, 152.6, 153.2, 153.5, 
153.6), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(74.6, 78, 
    81, 83.6, 86.2, 96.5, 104.1, 110.7, 118.6, 125.2, 130.9, 
    133.4, 135.9, 138.8, 141.7, 144.8, 148.1, 151.8, 155.8, 160.4, 
    164.8, 168.6, 171.7, 173.8, 175, 175.7, 176.1, 176.5, 176.9, 
    177.2, 177.5), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(74.9, 
78.1, 80.6, 83.4, 86, 96.5, 104.6, 111.8, 117.9, 124.1, 130.3, 
132.7, 135, 138.5, 141.8, 145.1, 148.1, 150.8, 153.9, 157.5, 
161.3, 164.5, 166, 166.7, 167.4, 167.9, 168.1, 168.5, 168.9, 
169.4, 169.8), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(77.6, 
81.1, 84, 87.2, 91.4, 98, 105.6, 112.2, 118.6, 124.2, 130.3, 
132.9, 135.5, 138.5, 141.4, 144.4, 147.6, 151.2, 154.9, 159, 
163.2, 166, 168.3, 169.8, 170.7, 171.5, 172.1, 172.5, 172.7, 
173.1, 173.5), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(68.6, 
73.6, 78.6, 83.6, 88.9, 96.8, 104.1, 111.8, 118.6, 124.7, 129.2, 
132.8, 136.5, 138.1, 139.4, 142.5, 145.4, 148.6, 152.2, 155.8, 
158.7, 160.8, 162.2, 163.1, 163.7, 164.3, 164.8, 165.4, 166, 
166.3, 166.8), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(79.9, 
82.6, 84.8, 88.6, 94, 99.6, 108.2, 116.2, 124, 131.1, 136.8, 
139.4, 142, 145, 148.1, 151.3, 154.8, 158.5, 161.6, 163.8, 165.3, 
166.2, 166.4, 166.6, 167, 167.5, 167.7, 168, 168.3, 168.4, 168.6
), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", "5", 
"6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76.1, 78.4, 
    82.3, 86, 89.2, 98.2, 106.7, 114.4, 121.9, 129.5, 135.2, 
    138.1, 140.8, 144.8, 148, 151.3, 154.7, 158.4, 161.7, 164.2, 
    165.6, 166.4, 167, 167.7, 168.1, 168.4, 168.5, 168.5, 168.6, 
    168.9, 169.2), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(81.3, 
84.2, 86.4, 88.9, 91.4, 101.1, 109.5, 115.8, 121.9, 130, 138.2, 
141.1, 144.3, 147.5, 150.5, 153.4, 156.2, 159.7, 163.8, 168.8, 
174.9, 181.2, 186.3, 189.6, 191.3, 192.1, 192.8, 193.2, 193.8, 
194.3, 195.1), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76.2, 
80.4, 83.2, 85.4, 87.6, 97, 104.6, 112.3, 118.9, 125, 130.1, 
133, 135.4, 137.5, 139.7, 142.2, 144.2, 146.2, 148.1, 149.8, 
151.6, 153.8, 156.3, 159.2, 163.3, 167.7, 171.5, 174.3, 176.1, 
177.4, 178.7), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76.8, 
79.8, 82.6, 84.7, 86.7, 94.2, 100.4, 107.1, 112.3, 118.6, 124, 
126.5, 128.9, 131.2, 133.4, 135.8, 138.4, 141, 143.6, 146.8, 
150.8, 155.1, 159.5, 163.3, 166.8, 167.8, 168.8, 169.8, 170.9, 
171.2, 171.5), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(74.1, 
78.4, 82.6, 85.4, 88.1, 98.6, 104.4, 111, 116.3, 123.2, 129.9, 
133, 136, 138.7, 141.4, 144, 146.4, 148.8, 151.4, 154.5, 157.7, 
162.2, 167.4, 172.5, 176.3, 178.5, 179.8, 180.7, 181.4, 181.6, 
181.8), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(74.2, 76.3, 
    78.3, 80.3, 82.2, 89.4, 96.9, 104.1, 110.7, 115.8, 121.7, 
    125.2, 128.5, 131.2, 134.2, 137.4, 140.5, 143.3, 145.9, 148.7, 
    152, 155.8, 160.4, 165.1, 168.5, 170.4, 171.6, 172.4, 172.5, 
    172.5, 172.5), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76.8, 
79.1, 81.1, 84.4, 87.4, 94, 102.4, 109.2, 116.1, 121.9, 127.8, 
129.8, 132.4, 135, 137.3, 139.7, 142, 144.1, 146.9, 150, 153.4, 
157.3, 161.6, 165.2, 168.8, 170.1, 171.5, 172.1, 172.6, 173.2, 
173.8), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(72.4, 76, 
    79.4, 82, 84.2, 93.2, 101.6, 109, 117.3, 122.9, 128.3, 130.9, 
    133.7, 136, 138, 139.9, 141.6, 143.4, 145.5, 147.8, 150.3, 
    152.8, 155.8, 159.2, 163.1, 166.5, 168.9, 170.2, 171.1, 171.8, 
    172.6), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
    "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(73.8, 
78.7, 83, 85.8, 88.4, 97.3, 106.7, 112.8, 119.1, 125.7, 132.3, 
135.4, 138.3, 141.3, 144.7, 147.9, 151.2, 154.5, 158.2, 162.3, 
166.5, 171.1, 175.2, 178.4, 180.8, 182.2, 183.2, 184, 184.7, 
185, 185.2), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(75.4, 
81, 84.9, 87.9, 90, 97.3, 102.8, 108.2, 113.5, 120.2, 125.7, 
127.9, 130.3, 133.2, 135.9, 137.9, 139.6, 141.5, 143.7, 146, 
148.6, 151.5, 154.3, 157.8, 161.8, 165.6, 168.7, 171, 171.6, 
172.3, 172.9), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(78.8, 
83.3, 87, 89.6, 91.4, 100.4, 111, 118.5, 125.8, 131.1, 138.4, 
141.5, 144.5, 147.5, 150.5, 153.6, 156.8, 160.5, 164.6, 169.2, 
174.3, 178.8, 181.9, 184.2, 185.6, 186.6, 187.1, 187.4, 187.8, 
188.2, 188.4), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76.9, 
79.9, 84.1, 88.5, 90.6, 96.6, 104.8, 112, 118.6, 124.8, 130.3, 
133.1, 135.8, 138.7, 141.7, 144.2, 146.6, 148.7, 150.5, 152.4, 
154, 158.9, 161.7, 165.1, 169.6, 174, 176.6, 178.6, 179.6, 180.2, 
181.6), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(81.6, 83.7, 
    86.3, 88.8, 92.2, 99.3, 105.8, 112.6, 119.6, 126.9, 133.8, 
    136.4, 139.9, 143.2, 146, 149, 151.8, 154.8, 158, 161.5, 
    165.3, 169.6, 174.3, 178.8, 182.1, 184.6, 186.1, 187.5, 188, 
    188.6, 189), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(78, 
81.8, 85, 86.4, 87.1, 96.2, 104, 111, 117.3, 124.1, 130, 133.6, 
136.8, 139.6, 142.2, 144.8, 147.4, 149.8, 151.9, 154.1, 158.2, 
163.3, 168.1, 173, 175.2, 177.4, 179.2, 180.6, 181.4, 181.9, 
182.4), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76.4, 79.4, 
    83.4, 87.6, 91.4, 101.2, 106.4, 113.3, 120.3, 128.8, 135, 
    137.8, 140.6, 143.4, 146.5, 149.6, 152.2, 155.3, 159.2, 163.9, 
    168.6, 172.8, 176.6, 179.4, 181.4, 182.6, 183.7, 184.4, 185, 
    185.7, 185.8), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76.4, 
81.2, 86, 89.2, 92.2, 101.3, 110.3, 117.3, 122.5, 129.5, 134.8, 
137.4, 140, 142.5, 145, 147.8, 150.5, 153.4, 157.4, 162, 166.6, 
170.7, 174, 176.1, 177.3, 177.9, 178.2, 178.3, 178.5, 178.5, 
178.7), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76.2, 79.2, 
    82.3, 85.4, 88.4, 101, 107.4, 114.8, 120.7, 128, 134.5, 137.4, 
    139.9, 142.5, 145.7, 148.7, 151.3, 154.3, 158.1, 162.8, 167.5, 
    171.5, 175.1, 178, 179.8, 181, 181.9, 182.7, 183.3, 183.4, 
    183.4), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
    "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(75, 
78.4, 82, 84, 85.9, 95.6, 102.1, 109.2, 117.5, 124.8, 131.5, 
134.9, 137.8, 140.7, 143.8, 146.8, 149.5, 152.4, 155.3, 158.9, 
163.6, 168.6, 173, 176.3, 178.5, 180, 181, 181.8, 182.2, 182.6, 
183), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", "5", 
"6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(79.7, 81.3, 
    83.3, 86.5, 88.9, 99.4, 104.1, 112.5, 119, 128, 133.6, 136.6, 
    139.5, 141.9, 144.8, 148.5, 152.3, 156.3, 161.2, 165.9, 169.5, 
    172.1, 174.2, 175.6, 176.4, 177, 177.3, 177.6, 177.3, 177, 
    177), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
    "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
    "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
    "16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(70, 
74.5, 78.7, 82.3, 85.1, 93.6, 101.9, 108.8, 115.3, 122, 127.9, 
130.9, 134.1, 136.8, 139.3, 141.6, 144, 146.1, 148.6, 151.7, 
155, 158.9, 163.3, 167.4, 170.4, 171.9, 173, 173.7, 174.2, 174.6, 
175), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", "5", 
"6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(73.8, 76.7, 
    79.3, 82.8, 86.4, 95.3, 102.2, 109.5, 116.1, 121.7, 128.3, 
    131.4, 134.3, 137, 140, 143, 145.6, 148.7, 152.3, 157, 162, 
    166.4, 169.8, 172.1, 173.7, 174.7, 175.5, 176.1, 176.4, 176.5, 
    176.8), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
    "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(75.3, 
79.1, 82.6, 85.1, 87.2, 95.6, 102.6, 109.7, 116.8, 121.7, 127.1, 
129.8, 132.5, 134.7, 136.7, 138.9, 141.5, 143.6, 145.8, 148, 
150, 152.5, 155.4, 158.9, 163, 166.8, 169.8, 172, 173.5, 174.9, 
176.4), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76.6, 79, 
    82.6, 86.6, 89, 95.3, 102.1, 108.5, 111.5, 119.4, 126.1, 
    128.8, 131.4, 134.3, 136.8, 139.7, 142.2, 144.1, 146.6, 150, 
    154, 158, 162.1, 166.5, 169.2, 170.7, 171.9, 172.8, 173.4, 
    173.8, 174), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(73, 
76, 78.7, 82.2, 84.6, 94.7, 104.9, 109, 115.3, 121.2, 126.5, 
130.4, 134.3, 136.6, 139.1, 141.6, 143.8, 146.3, 149, 151.6, 
154.2, 157.2, 160.6, 164.3, 168.6, 173, 176.2, 178, 179.1, 180.2, 
181), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", "5", 
"6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(75.1, 78.6, 
    81.9, 84, 85.6, 92.8, 100.6, 106.7, 112.5, 118.6, 123.7, 
    126.4, 129.1, 131.8, 134.5, 136.8, 139, 141.8, 145.3, 149.7, 
    154.4, 158.8, 162.2, 164.8, 167, 168, 168.8, 169.4, 169.7, 
    169.8, 170.1), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(77.4, 
81.6, 84.8, 88, 89.6, 96.5, 103.3, 108.7, 113.8, 120.1, 125.8, 
128.9, 132.1, 134.3, 136.9, 139.2, 141.6, 144.2, 146.7, 149.6, 
153.3, 157.7, 162.3, 166.1, 168.6, 170.5, 172.2, 173.1, 173.8, 
174.4, 175.2), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(73.2, 
76.2, 79, 81.8, 84.8, 95.3, 101.6, 109.3, 116, 122.7, 129.9, 
133.1, 136.2, 139.4, 142.6, 144.7, 147.9, 150.8, 153.5, 156.1, 
158.7, 161.1, 163.7, 166.8, 170.3, 174.3, 178.3, 181, 183.1, 
184.6, 185.1), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(78, 
82.2, 86.1, 88.9, 91.4, 101.3, 108, 114.9, 121.5, 128.3, 134, 
137, 140.1, 142.5, 145, 147.4, 149.5, 151.4, 153.2, 155.2, 157.1, 
159.2, 161.4, 163.6, 166.6, 170.9, 175, 178.1, 180.5, 182, 182.7
), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", "5", 
"6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76.5, 80, 
    82.8, 85.4, 88.4, 95.2, 102, 107.5, 114, 119.4, 124.2, 126.6, 
    129.1, 131.6, 134, 136.5, 138.8, 141, 143.3, 145.7, 148.1, 
    150.7, 154.4, 158.9, 162.7, 165.2, 166.9, 168, 168.7, 169.1, 
    169.4), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
    "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(78, 
80.6, 85.4, 90.2, 93.5, 103.6, 111, 117.9, 126.7, 133.6, 140.3, 
143.9, 147.4, 150.4, 153.4, 156.1, 159.1, 162.8, 167.1, 171.9, 
177.1, 181.8, 185.7, 188.8, 190.8, 192.2, 193, 193.6, 194, 194.1, 
194.3), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(74.9, 78.7, 
    81, 84.9, 87.7, 93.2, 104.2, 110, 116, 123.8, 130.6, 133.3, 
    136, 138.9, 141.9, 144.1, 146.2, 148.1, 150.1, 152.5, 155.1, 
    158.3, 162.4, 167.3, 171.6, 174.9, 177.4, 179, 180, 180.7, 
    181.1), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
    "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(74.2, 
78.3, 82.3, 86, 89.1, 97.1, 104.9, 112, 118.6, 124.7, 131.8, 
135, 138.2, 141.2, 143.9, 146.4, 149.5, 153.8, 158.4, 163.2, 
168, 172.4, 175.7, 177.6, 178.7, 179.8, 180.4, 180.8, 180.9, 
180.8, 181.3), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(78.7, 
83.3, 87, 90.4, 93.1, 103, 109.7, 118, 124.6, 132.3, 138.4, 141.6, 
144.8, 147.4, 150.5, 153.4, 156.1, 159.3, 163.7, 168.8, 174.2, 
179, 183.1, 186, 188, 189.6, 190.7, 191.3, 191.7, 192.2, 192.8
), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", "5", 
"6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(78, 82.6, 
    85.8, 88.4, 90.9, 99.1, 105.8, 112.2, 117.6, 123.4, 129.6, 
    132.3, 135, 137.3, 139.7, 142, 144.4, 146.5, 148.6, 150.7, 
    153.1, 156, 159.6, 163.5, 167.8, 170.3, 172.8, 174.5, 175.5, 
    176, 176.4), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76, 
81.2, 84.6, 87, 89.1, 94.6, 102, 107.4, 113, 119.4, 124.2, 127, 
129.8, 132.9, 136.1, 139, 141.7, 144.4, 147.4, 150.9, 155.9, 
161.5, 166.2, 169.6, 171.9, 172.9, 173.4, 173.8, 174.2, 174.2, 
174.1), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(76, 80.1, 
    85.9, 91.4, 95.2, 103.5, 111.6, 118.1, 126.3, 132.8, 139.1, 
    143.4, 147.5, 150.6, 154, 157.6, 160.9, 163.8, 166.3, 168.6, 
    171, 173.8, 177.3, 180.7, 183.4, 185.3, 186.2, 186.4, 186.7, 
    187.2, 188), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(68.8, 
73.5, 77.5, 80.8, 84, 95.2, 103.1, 111.1, 118.4, 124.9, 130.7, 
134, 137.5, 140.3, 143, 145.5, 148, 150.8, 153.6, 157.3, 162.1, 
167, 171.2, 174.4, 176.8, 178.4, 179.1, 179.7, 180.1, 180.5, 
180.8), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", "4", 
"5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", "11.5", 
"12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", "16", 
"16.5", "17", "17.5", "18"))), .Names = c("args", "vals")), structure(list(
    args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 7, 8, 8.5, 9, 
    9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 14.5, 15, 
    15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(82.2, 88.9, 
    90.9, 93, 95.3, 103.8, 111.8, 117.1, 123.7, 130.4, 136.4, 
    139.3, 142.2, 145.2, 148.3, 151.2, 154.2, 157.6, 161.8, 166.5, 
    171.1, 174.9, 177.9, 180.1, 181.3, 181.8, 182.2, 182.7, 183.1, 
    183.4, 183.7), .Names = c("1", "1.25", "1.5", "1.75", "2", 
    "3", "4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", 
    "11", "11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", 
    "15.5", "16", "16.5", "17", "17.5", "18"))), .Names = c("args", 
"vals")), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 
5, 6, 7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 
14, 14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(77, 
82.5, 85.6, 87.9, 90.3, 98.3, 107.2, 114.6, 121.9, 129.2, 135.9, 
139.1, 142.2, 145, 147.8, 150.5, 153.5, 157.5, 161.5, 165.5, 
169.7, 173.1, 175.6, 177.2, 178.3, 179, 179.2, 179.3, 179.8, 
180.3, 180.7), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
)), structure(list(args = c(1, 1.25, 1.5, 1.75, 2, 3, 4, 5, 6, 
7, 8, 8.5, 9, 9.5, 10, 10.5, 11, 11.5, 12, 12.5, 13, 13.5, 14, 
14.5, 15, 15.5, 16, 16.5, 17, 17.5, 18), vals = structure(c(75, 
79.2, 82.2, 84.6, 87, 95.8, 103.1, 110.2, 116.1, 122.2, 127.7, 
130.7, 133.7, 136.8, 139.8, 142.6, 145.1, 147.3, 150.2, 153.3, 
156.7, 160.5, 164.1, 167.7, 171, 173.1, 174.7, 175.6, 176.1, 
176.3, 176.4), .Names = c("1", "1.25", "1.5", "1.75", "2", "3", 
"4", "5", "6", "7", "8", "8.5", "9", "9.5", "10", "10.5", "11", 
"11.5", "12", "12.5", "13", "13.5", "14", "14.5", "15", "15.5", 
"16", "16.5", "17", "17.5", "18"))), .Names = c("args", "vals"
))), labels = list("girl", "girl", "girl", "girl", "girl", "girl", 
    "girl", "girl", "girl", "girl", "girl", "girl", "girl", "girl", 
    "girl", "girl", "girl", "girl", "girl", "girl", "girl", "girl", 
    "girl", "girl", "girl", "girl", "girl", "girl", "girl", "girl", 
    "girl", "girl", "girl", "girl", "girl", "girl", "girl", "girl", 
    "girl", "girl", "girl", "girl", "girl", "girl", "girl", "girl", 
    "girl", "girl", "girl", "girl", "girl", "girl", "girl", "girl", 
    "boy", "boy", "boy", "boy", "boy", "boy", "boy", "boy", "boy", 
    "boy", "boy", "boy", "boy", "boy", "boy", "boy", "boy", "boy", 
    "boy", "boy", "boy", "boy", "boy", "boy", "boy", "boy", "boy", 
    "boy", "boy", "boy", "boy", "boy", "boy", "boy", "boy", "boy", 
    "boy", "boy", "boy")))
)
